# Source with dec 6166 and NSB tuning

## 20220905

## Short description of the config

Config for a source src4 with dec 6166 and NSB tuning:

"image_modifier":{
  "increase_nsb": true,
  "extra_noise_in_dim_pixels": 1.82,
  "extra_bias_in_dim_pixels": 0.815,
  "transition_charge": 8,
  "extra_noise_in_bright_pixels": 4.098
}
